import Layout from '@/layout/index.vue'

/**
 * 商户中心路由
 */
export const mchRoutes = [
  {
    path: '/business',
    component: Layout,
    hidden: false,
    alwaysShow: true,
    meta: {
      title: '经营管理'
    },
    children: [
      {
        path: 'store',
        component: () => import('../views/mch/store'),
        hidden: false,
        name: "MyStore",
        meta: {
          noCache: false,
          title: '我的店铺',
        }
      },
      {
        path: 'store/:storeId',
        component: () => import('../views/mch/store/detail.vue'),
        hidden: true,
        name: "MyStoreDetail",
        meta: {
          noCache: false,
          title: '店铺详情',
        }
      },
      {
        path: 'suit',
        component: () => import('@/views/mch/suit/index.vue'),
        hidden: false,
        name: "MchSuit",
        meta: {
          noCache: false,
          title: '套餐管理',
        }
      },
    ]
  },
  {
    path: '/device',
    component: Layout,
    hidden: false,
    alwaysShow: true,
    meta: {
      title: '设备管理'
    },
    children: [
      {
        path: '',
        component: () => import('@/views/mch/device'),
        hidden: false,
        name: "MyDevice",
        meta: {
          noCache: false,
          title: '我的设备',
        }
      },
      {
        path: ':deviceId',
        component: () => import('@/views/mch/device/detail.vue'),
        hidden: true,
        name: "MyDeviceDetail",
        meta: {
          noCache: false,
          title: '设备详情',
        }
      },
    ]
  },
  {
    path: '/bill',
    component: Layout,
    hidden: false,
    alwaysShow: true,
    meta: {
      title: '订单管理'
    },
    children: [
      {
        path: 'recharge',
        component: () => import('../views/mch/recharge'),
        hidden: false,
        name: "MchRecharge",
        meta: {
          noCache: false,
          title: '充值订单',
        }
      },
      {
        path: 'refund',
        component: () => import('@/views/mch/refund'),
        hidden: false,
        name: "MchRefund",
        meta: {
          noCache: false,
          title: '订单退款',
        }
      },
      {
        path: 'recharge/:billId',
        component: () => import('@/views/mch/recharge/detail.vue'),
        hidden: true,
        name: "MchRechargeDetail",
        meta: {
          noCache: false,
          title: '订单详情',
        }
      },
    ]
  },
  {
    path: '/money',
    component: Layout,
    hidden: false,
    alwaysShow: true,
    meta: {
      title: '财务管理'
    },
    children: [
      {
        path: 'withdraw',
        component: () => import('@/views/mch/withdraw/index.vue'),
        hidden: false,
        name: "MchWithdraw",
        meta: {
          noCache: false,
          title: '提现记录',
        }
      },
      {
        path: 'withdraw/:billId',
        component: () => import('@/views/mch/withdraw/detail.vue'),
        hidden: true,
        name: "MchWithdrawDetail",
        meta: {
          noCache: false,
          title: '提现详情',
        }
      },
      {
        path: 'recordBalance',
        component: () => import('@/views/index.vue'),
        hidden: false,
        name: "MchRecordBalance",
        meta: {
          noCache: false,
          title: '收支明细',
        }
      },
      {
        path: 'receiveBill',
        component: () => import('@/views/index.vue'),
        hidden: false,
        name: "MchReceiveBill",
        meta: {
          noCache: false,
          title: '应付账单',
        }
      },
    ]
  },
  {
    path: '/dev',
    component: Layout,
    hidden: false,
    alwaysShow: true,
    meta: {
      title: '开发管理'
    },
    children: [
      {
        path: 'access',
        hidden: false,
        component: () => import('@/views/index.vue'),
        name: "MyAccess",
        meta: {
          noCache: false,
          title: '秘钥管理'
        },
      },
      {
        path: 'https://www.baidu.com',
        hidden: false,
        meta: {
          title: '开发文档'
        },
      }
    ]
  },
]
